@@ -1,3 +1,6 @@
+"""
+Wrapper for full `CHANGELOG.md` content.
+"""
 from typing import Iterator, List, Optional, Type, TypeVar
 
 from newversion import Version
@@ -9,6 +12,15 @@ _R = TypeVar("_R", bound="ChangeLog")
 
 
 class ChangeLog:
+    """
+    Wrapper for full `CHANGELOG.md` content.
+
+    Arguments:
+        head -- Head of changelog
+        released -- Released content
+        unrelease -- Unreleased content
+    """
+
     PARTS_DELIM = "\n\n"
 
     # Released section title in CHANGELOG.md
@@ -18,10 +30,10 @@ class ChangeLog:
     UNRELEASED_MARKER = "## [Unreleased]"
 
     def __init__(self, head: str, released: str, unreleased: str) -> None:
-        self.head = head
+        self.head: str = head
         self._released = released.strip()
         self._released_records: List[Record] = []
-        self._unreleased = Record(Version.zero(), created="", body=unreleased)
+        self._unreleased = Record(Version.zero(), created="", text=unreleased)
 
     @property
     def released(self) -> List[Record]:
@@ -32,6 +44,12 @@ class ChangeLog:
 
     @classmethod
     def parse(cls: Type[_R], text: str) -> _R:
+        """
+        Parse from `CHANGELOG.md` content.
+
+        Arguments:
+            text -- CHANGELOG.md text content.
+        """
         head = dedent(text)
         released = ""
         unreleased = ""
@@ -56,6 +74,9 @@ class ChangeLog:
         return self._released
 
     def render(self) -> str:
+        """
+        Render to string.
+        """
         parts = [self.head]
         parts.append(self._unreleased.render())
         if self.released:
@@ -64,15 +85,36 @@ class ChangeLog:
         return self.PARTS_DELIM.join(parts).strip() + "\n"
 
     def get_latest(self) -> Optional[Record]:
+        """
+        Get latest release record.
+
+        Returns:
+            Release record or None.
+        """
         for record in self.iterate_records():
             return record
 
         return None
 
     def get_unreleased(self) -> Record:
+        """
+        Get unreleased record.
+
+        Returns:
+            Release record.
+        """
         return self._unreleased
 
     def get_record(self, version: Version) -> Optional[Record]:
+        """
+        Get record by release version.
+
+        Arguments:
+            version -- release version.
+
+        Returns:
+            Release record or None.
+        """
         for record in self.iterate_records():
             if record.version == version:
                 return record
@@ -80,6 +122,12 @@ class ChangeLog:
         return None
 
     def iterate_records(self) -> Iterator[Record]:
+        """
+        Iterate over release records from newest to oldest.
+
+        Yields:
+            Release record.
+        """
         for record_text in self._released.split(self.RELEASED_MARKER):
             if not record_text.strip():
                 continue
@@ -87,6 +135,9 @@ class ChangeLog:
             yield record
 
     def format_released(self) -> None:
+        """
+        Format all released records.
+        """
         record_rendered = []
         for record in self.released:
             record_rendered.append(record.render())
@@ -94,6 +145,12 @@ class ChangeLog:
         self._released = "\n\n".join(record_rendered)
 
     def add_release(self, record: Record) -> None:
+        """
+        Add new release.
+
+        Arguments:
+            record -- New release record.
+        """
         if self._released:
             self._released = f"{record.render()}\n\n{self._released}"
             return
@@ -101,6 +158,12 @@ class ChangeLog:
         self._released = record.render()
 
     def update_release(self, record: Record) -> None:
+        """
+        Add or update release `record`.
+
+        Arguments:
+            record -- Record to update.
+        """
         if record.version == Version.zero():
             self._unreleased.body = record.body
             return
