@@ -3,6 +3,9 @@ from pathlib import Path
 
 
 def strip_empty_lines(text: str) -> str:
+    """
+    Remove empty lines from the start and end of `text`.
+    """
     lines = text.splitlines()
     while lines and not lines[0].strip():
         lines.pop(0)
@@ -13,10 +16,16 @@ def strip_empty_lines(text: str) -> str:
 
 
 def dedent(text: str) -> str:
+    """
+    Dendent text and remove empty lines from beginning and end.
+    """
     return textwrap.dedent(strip_empty_lines(text))
 
 
 def print_path(path: Path) -> str:
+    """
+    Print path relative to current workdir
+    """
     if path.is_absolute():
         cwd = Path.cwd()
         if path == cwd or path.parts <= cwd.parts:
